pub fn calculate_n_test_queries(
security_bits: usize,
log_inv_rate: usize,
) -> usizeExpand description
Calculates the number of test queries required to achieve a target soundness error.
This chooses a number of test queries so that the soundness error of the FRI query phase is
at most $2^{-t}$, where $t$ is the threshold security_bits. This does not account for the
soundness error from the FRI folding phase or any other protocols, only the query phase. This
sets the proximity parameter for FRI to the code’s unique decoding radius. See DP24,
Section 5.2, for concrete soundness analysis.